# Table of Contents

- [setup-in-servicenow](<./setup-in-servicenow.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Setup in ServiceNow](<./Setup-in-ServiceNow.md>)
  - [Create a Technical User](<./Setup-in-ServiceNow/Create-a-Technical-User.md>)
  - [Installation of LeanIX Integration App](<./Setup-in-ServiceNow/Installation-of-LeanIX-Integration-App.md>)
  - [Update SAP LeanIX Integration App (for admins)](<./Setup-in-ServiceNow/Update-SAP-LeanIX-Integration-App-for-admins.md>)
  - [Configuration and Setup of Integration User](<./Setup-in-ServiceNow/Configuration-and-Setup-of-Integration-User.md>)
  - [Create an Integration user](<./Setup-in-ServiceNow/Create-an-Integration-user.md>)
  - [Customised System Tables in ServiceNow](<./Setup-in-ServiceNow/Customised-System-Tables-in-ServiceNow.md>)
  - [Optional: Add ACLs in ServiceNow](<./Setup-in-ServiceNow/Optional-Add-ACLs-in-ServiceNow.md>)
  - [Optional: Enable OAuth 2.0 for Authentication](<./Setup-in-ServiceNow/Optional-Enable-OAuth-2.0-for-Authentication.md>)
  - [Optional: Separate Queue for SAP LeanIX Integration](<./Setup-in-ServiceNow/Optional-Separate-Queue-for-SAP-LeanIX-Integration.md>)
  - [Optional: Review client-adapted ServiceNow Instances](<./Setup-in-ServiceNow/Optional-Review-client-adapted-ServiceNow-Instances.md>)
  - [Was this page helpful?](<./Setup-in-ServiceNow/Was-this-page-helpful.md>)
